API Reference
=============

This section contains the complete API reference for MLPY.

Core Modules
------------

.. toctree::
   :maxdepth: 2

   mlpy.base
   mlpy.core

Tasks
-----

.. toctree::
   :maxdepth: 2

   mlpy.tasks

Learners
--------

.. toctree::
   :maxdepth: 2

   mlpy.learners
   mlpy.learners.baseline
   mlpy.learners.ensemble
   mlpy.learners.sklearn

Measures
--------

.. toctree::
   :maxdepth: 2

   mlpy.measures

Resamplings
-----------

.. toctree::
   :maxdepth: 2

   mlpy.resamplings

Pipelines
---------

.. toctree::
   :maxdepth: 2

   mlpy.pipelines

AutoML
------

.. toctree::
   :maxdepth: 2

   mlpy.automl

Validation
----------

.. toctree::
   :maxdepth: 2

   mlpy.validation

Visualization
-------------

.. toctree::
   :maxdepth: 2

   mlpy.visualization

Utilities
---------

.. toctree::
   :maxdepth: 2

   mlpy.utils